\layout {
  \context {
    \Voice
    \consists "Melody_engraver"
    \override Stem #'neutral-direction = #'()
  }
}

global = {
  \key g \major
  \numericTimeSignature
  \time 3/4
  \tempo "Lively"
  \dynamicUp
}

#(define-markup-command (arrow-at-angle layout props angle-deg length fill)
   (number? number? boolean?)
   (let* (
           ;; PI-OVER-180 and degrees->radians are taken from flag-styles.scm
           (PI-OVER-180 (/ (atan 1 1) 45))
           (degrees->radians (lambda (degrees) (* degrees PI-OVER-180)))
           (angle-rad (degrees->radians angle-deg))
           (target-x (* length (cos angle-rad)))
           (target-y (* length (sin angle-rad))))
     (interpret-markup layout props
       (markup
        #:translate (cons (/ target-x 2) (/ target-y 2))
        #:rotate angle-deg
        #:translate (cons (/ length -2) 0)
        #:concat (#:draw-line (cons length 0)
                   #:arrow-head X RIGHT fill)))))

splitStaffBarLineMarkup = \markup \with-dimensions #'(0 . 0) #'(0 . 0) {
  \combine
  \arrow-at-angle #45 #(sqrt 8) ##f
  \arrow-at-angle #-45 #(sqrt 8) ##f
}

splitStaffBarLine = {
  \once \override Staff.BarLine.stencil =
  #(lambda (grob)
     (ly:stencil-combine-at-edge
      (ly:bar-line::print grob)
      X RIGHT
      (grob-interpret-markup grob splitStaffBarLineMarkup)
      0))
  \break
}

downStaffBarLine = { 
  \once \override Staff.BarLine #'stencil =
  #(lambda (grob) 
     (ly:stencil-combine-at-edge 
      (ly:bar-line::print grob) 
      X RIGHT
      (grob-interpret-markup grob downStaffBarLineMarkup)
      0)) 
  \break
}

downStaffBarLineMarkup = \markup \with-dimensions #'(0 . 0) #'(0 . 0) {
  \arrow-at-angle #-45 #(sqrt 8) ##f
}

mfFMarkup = \markup {\concat {\dynamic mf \normal-text \italic "–" \dynamic f }}
mfF = #(make-dynamic-script mfFMarkup)

%turn parentheses into brackets for final fermata | still needs override within music
#(define-public (bracket-stencils grob)
  (let ((lp (grob-interpret-markup grob (markup #:fontsize 3.5 #:translate (cons -0.3 -0.5) "[")))
        (rp (grob-interpret-markup grob (markup #:fontsize 3.5 #:translate (cons -0.3 -0.5) "]"))))
    (list lp rp)))

sopranoOneA = \relative c'' {
  \global
  \mark "Verse I"
  \repeat volta 2 {
    
    g4\mf g d' | b4. a8 g4 | fis e d | 
    e2 fis4~ | \time 2/4 fis g | \time 4/4 a2 g |} \break
  \time 3/4 d'4\f d d | e2. \breathe  | b4 c8 c d4(~ | d8 [e d b] d4~ | d8[ e] d4. e8 | d4.) c8 b4 |
  a2 \breathe b8\p ([g]) |<< {a2}{s8\> s8 s8 s8\!} >> \breathe b8 ([ g]) |
  d'2.\> \breathe | d,4\f e4. fis8 | \time 4/4 g2 a4 b | \time 7/4 c2 (b4. a8 g4 a2) | \time 3/4
  <<{ g2.} \new Voice {\voiceTwo b2.}>>  | \bar "||" \pageBreak
}
sopranoOneB = \relative c'' {
  %verse2
  \mark "Verse II"
  \repeat volta 2 {R2. | g4\mfF g d' b2 b4 ~ b8 b c4 d ~ \time 4/4 d8 \breathe
                   d e4 d4. d8 c4 b8 b a2
                   \time 2/4 g2} \break
  \time 3/4 R2. b4\p b b d2 r4 a4 a a \time 4/4 c 
  c4. d8 b4 a4 \breathe 
  d4. d8 c4 b4. ( a8 [b c d e] \time 3/4 d4.) c8 b4 a2 r4  | \splitStaffBarLine
  \set Staff.shortInstrumentName = "S1"

  d,\mf e fis 
  
  g a b  \time 2/4 a a8 \breathe d b4 b8 \breathe d b4 b8 \breathe d \>
  \time 4/4 b4 ( d4. e8 [d c] \time 2/4 d4)
  %turn parentheses into brackets
  \once \override ParenthesesItem.stencils = #bracket-stencils
  d\!-\parenthesize \fermata
  \once \override Score.RehearsalMark #'self-alignment-X = #RIGHT
  \mark \markup {"Verse I da capo" } \bar "|."
  
}

sopranoOneUpToSopTwoEntrance = \relative c'' {
  \global
  \mark "Verse 1"
  \repeat volta 2 {
    
    g4\mf g d' | b4. a8 g4 | fis e d | 
    e2 fis4~ | \time 2/4 fis g | \time 4/4 a2 g |} \break
  \time 3/4 d'4\f d d | e2. \breathe  | b4 c8 c d4(~ | d8 [e d b] d4~ | d8[ e] d4. e8 | d4.) c8 b4 |
  a2 \breathe b8\p ([g]) |<< {a2}{s8\> s8 s8 s8\!} >> \breathe b8 ([ g]) |
  d'2.\> \breathe | d,4\f e4. fis8 | \time 4/4 g2 a4 b | \time 7/4 c2 (b4. a8 g4 a2) | \time 3/4
  <<{ g2.} \new Voice {\voiceTwo b2.}>>  | \bar "||" \pageBreak
  %verse2
  \mark "Verse 2"
  \repeat volta 2 {R2. | g4 g d' b2 b4 ~ b8 b c4 d ~ \time 4/4 d8 \breathe
                   d e4 d4. d8 c4 b8 b a2
                   \time 2/4 g2} \break
  \time 3/4 R2. b4\p b b d2 r4 a4 a a \time 4/4 c \breathe
  c4. d8 b4 a4 \breathe 
  d4. d8 c4 b4. ( a8 [b c d e] \time 3/4 d4.) c8 b4 a2 r4
}

sopranoTwoRests = {
  \global
  \repeat volta 2 {s2.*4 | s2 | s1 |}
  s2.*10 | 
  s1 | s1 s2. | s2. |
  %verse2
  \repeat volta 2 {s2.*4 | s1*2 | s2}
  s2.*4 | s1*3 | s2.*2 | 
}

sopranoTwoNotes = \relative c' {
  d4\mf e fis | g4 a b a2 | g8 \breathe a g4 |  g8 \breathe a g4 | g8 \breathe a g2( e4 | g4) 
  %turn parentheses into brackets
  \once \override ParenthesesItem.stencils = #bracket-stencils
  b-\parenthesize \fermata \bar "|."
}

sopranoTwoB = \relative c' {
  %verse2
  \repeat volta 2 {s2.*4 | s1*2 | s2}
  s2.*4 | s1*3 | s2.*2 |
  \sopranoTwoNotes
}

altoA = \relative c'' {
  \global
  \repeat volta 2 {g4.\mf fis8 e4 d2 d4 ~ d8 d g4. g8
                   e8 e a4. a8 \time 2/4 fis4 b \time 4/4 a8 g fis4 g2 }
  \time 3/4  b4.\f a8 b4 g2. \breathe g4 g8 e g4 ( ~ g8 [e g a] b4 ~ b8 [c] b4. c8 b4.)
  a8 g4 fis2 \breathe g4\p << {fis2}{s8\> s8 s8 s8\!} >>
  \breathe g4 d2.\> \breathe b4\f b b \time 4/4 e2 d4 d
  \time 7/4 c8 ([d e fis?] g4. fis8 e2 fis4) \time 3/4 g2. \bar "||"
}
altoB = \relative c' {
  %verse2
  \repeat volta 2 {R2. | R | g4\mfF g d' b2 b4 \time 4/4 d g g8 g g4 ~ g8 fis g4 d2 \time 2/4
                   <<{ d2} \new Voice {\voiceTwo b2}>>  }
  \time 3/4
  R2. g'4\p g g fis2 r4 f4. e8 d4 \time 4/4 e a4. b8 g4 fis? \breathe
  b4. c8 a4 g4. ( fis8 [g a b c] \time 3/4 b4.) a8 g4 fis2 r4 | \downStaffBarLine
  b,4\mf c d 
  e fis g \time 2/4 d2 d ~ d4 \breathe d4\> \time 4/4 d2 d ~d\! \bar "|."
}

tenor = \relative c' {
  \global
  \repeat volta 2 {R2. | g4\mf g d' | b2 b8 b | c4. b8 a4 | \time 2/4 d c ~ |
                   \time 4/4 c8 b a4 b2 | }
  \time 3/4 R2. c4.\f b8 c4 d2. \breathe d,4. e8 fis4 g2 g4 ~ g g2 d \breathe g4\p d2 r4
  d4\f e4. fis8 g2 \breathe g4 \time 4/4 g  e fis4.\breathe g8 \time 7/4 a2 g4 a b (c d)
  \time 3/4 d2. \bar "||"
  
}

bassA = \relative c' {
  \global
  \repeat volta 2 { R2. | g4.\mf fis8 e4 d c b a a8 a
                    d4 ~ \time 2/4 d e \time 4/4 c d g,2 }
  \time 3/4 R2. e'4\f e c g'2. \breathe b,4. c8 d4 d2 b4 ~ b g2 d'2 \breathe g,4\p d'2 r4
  b4\f b d g4. ( fis8 e) d \time 4/4 c4. e8 a4. (g8 \time 7/4 f [e] d4) e c d2.
  \time 3/4 <g g,>2. \bar "||"
}

bassB = \relative c' {

  \repeat volta 2 { g4\mfF g d' b4. a8 g 4 fis e d e2 fis8 \breathe fis \time 4/4 g8.
                    ([a16 b8] c4) c8 b4 a (g2 fis4) \time 2/4 g2 }\time 3/4 d'4\p d d e2 r4 b c d d4. c8 b4
  \time 4/4 a2 r R1 R1 \time 3/4 R2. d,4\mf e fis \downStaffBarLine
  g2 b4 ~  
  b8 c a4 (g ~ \time 2/4 g8 [fis16 e] fis4) g2 ~ g4 \breathe g\>
  \time 4/4 g2 g ~ \time 2/4 g\! \bar "|."
}

sopranoOneVerseOne = \lyricmode {
  Praise to the Lord, the Al -- migh -- ty, the King of __ cre -- a -- tion!
  
  All ye who hear,
  Now to His tem -- ple draw near, draw near, draw near;
  Praise Him in glad a -- do -- ra -- tion!
  
  Praise to the Lord! Who o'er all things, o'er all things so won -- drous -- ly reign -- eth,
  
  Hast Thou not seen, hast thou not seen 
  How thy de -- sires, how thy de -- sires __ e'er have been
  Grant -- ed in what He or -- dain -- eth, 
  or -- dain -- eth, or -- dain -- eth,  or -- dain -- eth?
}

sopranoTwoVerseOne = \lyricmode {
  Grant -- ed in what He or -- dain -- eth, 
  or -- dain -- eth, or -- dain -- eth,  or -- dain -- eth?
}

altoVerseOne = \lyricmode {
  Praise to the Lord, the __ Al -- migh -- ty, the Al -- migh -- ty, the King of cre -- a -- tion!
  
  All ye who hear,
  Now to His tem -- ple draw near, draw near, draw near;
  Praise Him in glad a -- do -- ra -- tion!
  
  Praise to the Lord! Who o'er all things so won -- drous -- ly reign -- eth,
  
  Hast Thou not seen, hast thou not seen 
  How thy de -- sires, how thy de -- sires __ e'er have been
  Grant -- ed in what He or -- dain -- eth, __ or -- dain -- eth? __
  
}

tenorVerseOne = \lyricmode {
  Praise to the Lord, the Al -- migh -- ty, the King of __ cre -- a -- tion!
  
  All ye who hear,
  Now to His tem -- ple __ draw near, draw near; 
  Praise Him in glad, praise Him in glad, in glad a -- do -- ra -- tion!
  
}

bassVerseOne = \lyricmode {
  Praise to the Lord, the Al -- migh -- ty, the King __ of cre -- a -- tion!
  
  All ye who hear,
  Now to His tem -- ple __ draw near, draw near;
  Praise Him in glad, praise him in glad a -- do -- ra -- tion!
  
  Praise to the Lord! Who o'er all things so won -- drous, so won -- drous -- ly reign -- eth,

  Hast Thou not seen 
  How thy de -- sires e'er have been
  Grant -- ed in what He or -- dain -- eth, __ or -- dain -- eth? __
}

sopranoOneVerseTwo = \lyricmode {
  O my soul, praise Him, for He is thy health and __ sal -- va -- tion!
  \repeat unfold 23 {\skip 4}
  Shel -- ters thee un -- der His wings, yea, so gen -- tly, so gen -- tly sus -- tain -- eth;
}

altoVerseTwo = \lyricmode {
  O my soul, praise Him, __ for He, He is thy health, thy health and thy sal -- va -- tion!
  \repeat unfold 23 {\skip 4}
  Shel -- ters thee un -- der His wings, yea, so gen -- tly, sus -- tain -- eth;
}

tenorVerseTwo = \lyricmode {
  O my soul, praise Him, for He is thy health and __ sal -- va -- tion!
  
}

bassVerseTwo = \lyricmode {
  O my soul, praise Him, for He is thy health __ and sal -- va -- tion!
  \repeat unfold 25 {\skip 4}
  Shel -- ters thee un -- der His wings, yea, so gen -- tly, so gen -- tly sus -- tain -- eth;
  
}